@@ -15,7 +15,7 @@ namespace citygml {
         MaterialElementParser(CityGMLDocumentParser& documentParser, CityGMLFactory& factory, std::shared_ptr<CityGMLLogger> logger, std::function<void(std::shared_ptr<Material>)> callback);
 
         // ElementParser interface
-        virtual std::string elementParserName() const;
+        virtual std::string elementParserName() const override;
         bool handlesElement(const NodeType::XMLNode &node) const override;
 
     protected:
