@@ -1,8 +1,8 @@
-#include "citygml/linearring.h"
-#include "citygml/texturecoordinates.h"
-#include "citygml/texture.h"
-#include "citygml/texturetargetdefinition.h"
-#include "citygml/citygmllogger.h"
+#include <citygml/linearring.h>
+#include <citygml/texturecoordinates.h>
+#include <citygml/texture.h>
+#include <citygml/texturetargetdefinition.h>
+#include <citygml/citygmllogger.h>
 #include <float.h>
 #include <assert.h>
 
@@ -66,7 +66,7 @@ namespace citygml {
     {
         // Currently TextureCoordinates sharing via xlink is not supported (every TextureTargetDefinition is the
         // sole owner of its TextureCoordinate objects... if this ever changes use an unordered_set for the texture coordinates
-        std::vector<std::shared_ptr<TextureCoordinates>> coordinatesList;
+        std::vector<std::shared_ptr<TextureCoordinates> > coordinatesList;
 
         bool textureCoordinatesVerticesMismatch = false;
 
